genshi.template.eval.UndefinedError

Package genshi :: Package template :: Module eval :: Class UndefinedError |

# Class UndefinedError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                  base.TemplateError --+
                                       |
               base.TemplateRuntimeError --+
                                           |
                                          UndefinedError

Exception thrown when a template expression attempts to access a variable not defined in the context.

See Also: LenientLookup, StrictLookup

Instance Methods
__init__(self, name, owner=UNDEFINED) Create the exception. |
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables
Inherited from `base.TemplateError`: `filename`, `lineno`, `msg`, `offset`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, name, owner=UNDEFINED) (Constructor) |
Create the exception. Parameters: `message` - the error message `filename` - the filename of the template `lineno` - the number of line in the template at which the error occurred `offset` - the column number at which the error occurred Overrides: object.__init__ (inherited documentation)